@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; coding: utf-8 -*-
- * gtksourcecompletionproviderwords.c
+ *
  * This file is part of GtkSourceView
  *
  * Copyright (C) 2009 - Jesse van den Kieboom
@@ -34,14 +34,13 @@
 #endif
 
 #include "gtksourcecompletionwords.h"
+#include <string.h>
+#include <glib/gi18n-lib.h>
 #include "gtksourcecompletionwordslibrary.h"
 #include "gtksourcecompletionwordsbuffer.h"
 #include "gtksourcecompletionwordsutils.h"
 #include "gtksourceview/gtksource.h"
-#include "gtksourceview/gtksourceview-enumtypes.h"
-#include "gtksourceview/gtksourceview-i18n.h"
-
-#include <string.h>
+#include "gtksourceview/gtksource-enumtypes.h"
 
 #define BUFFER_KEY "GtkSourceCompletionWordsBufferKey"
 
