@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; coding: utf-8 -*- */
-/* test-buffer-input-stream.c
+/*
  * This file is part of GtkSourceView
  *
  * Copyright (C) 2010 - Ignacio Casal Quinteiro
@@ -20,6 +20,7 @@
 
 #include <gio/gio.h>
 #include <gtk/gtk.h>
+#include <stdlib.h>
 #include <string.h>
 #include <gtksourceview/gtksource.h>
 #include "gtksourceview/gtksourcebufferinputstream.h"
@@ -63,7 +64,7 @@ test_consecutive_read (const gchar          *inbuf,
 	g_assert_cmpstr (b, ==, outbuf);
 
 	close = g_input_stream_close (G_INPUT_STREAM (in), NULL, &err);
-	g_assert (close);
+	g_assert_true (close);
 	g_assert_no_error (err);
 
 	g_object_unref (buf);
